#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage			 : http://jmpacquet.free.fr/wmcalclock/
# source location    : http://jmpacquet.free.fr/wmcalclock/wmCalClock-1.26.tar.gz
# last revised       : 16.9.2009
# dep                : 

softname='wmCalClock'
softversion='1.26'
packageversion='1fb'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://jmpacquet.free.fr/$softname/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/bin
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/man/man1
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
          |-----handy-ruler------------------------------------------------------|
wmCalClock: wmCalClock (A dock.app which simply tells time and date)
wmCalClock:
wmCalClock: wmCalclock is a dock app specifically written for Window Maker, 
wmCalClock: but will work with other window managers. Some features include 
wmCalClock: antialiased text display, with the ability to choose between 
wmCalClock: different fonts, and colors. 12 and 24 hour time, Greenwich time, 
wmCalClock: Greenwich Mean Sidereal Time, and Local Sidereal Time.
wmCalClock: 
wmCalClock: 
wmCalClock: 
wmCalClock:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src/Src

# build

    export OPT="-O2 -march=$arch -mtune=$cpu"
    sed -i 's|CFLAGS = -O2 -Wall|CFLAGS = -O2 -march=i486 -mtune=i686 -Wall  |g' Makefile
    make
    
	cp -v wmCalClock $dest/usr/bin
    cp -v wmCalClock.1 $dest/usr/man/man1

# add 'default' files
    cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      BUGS TODO HINTS README INSTALL CHANGES COPYING\
      $dest/usr/doc/$softname-$softversion

# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# SalixBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "libX11,libXau,libXdmcp,libXext,libXpm,libxcb" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/divers/salix/xap/wmcalclock/build-wmCalClock.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
